#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-explicit-imports-plugin
version:              2.3.0.0
visibility:           public
id:                   hls-explicit-imports-plugin-2.3.0.0-HNlQjhXVsq9AZgGydjaws2
key:                  hls-explicit-imports-plugin-2.3.0.0-HNlQjhXVsq9AZgGydjaws2
license:              Apache-2.0
maintainer:           pepeiborra@gmail.com
author:               Pepe Iborra
synopsis:             Explicit imports plugin for Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  d6ce87d06971664a578da71f8c1fba7d
exposed:              True
exposed-modules:      Ide.Plugin.ExplicitImports
import-dirs:
    /usr/lib/ghc-9.6.6/site-local/hls-explicit-imports-plugin-2.3.0.0

library-dirs:
    /usr/lib/ghc-9.6.6/site-local/hls-explicit-imports-plugin-2.3.0.0

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/hls-explicit-imports-plugin-2.3.0.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-explicit-imports-plugin
hs-libraries:
    HShls-explicit-imports-plugin-2.3.0.0-HNlQjhXVsq9AZgGydjaws2

depends:
    aeson-2.2.1.0-FtPGfJZ8He1Ka7nmfurK0L base-4.18.2.1 containers-0.6.7
    deepseq-1.4.8.1 ghc-9.6.6 ghcide-2.3.0.0-3935vir6BTc9L9sTVS8AJW
    hls-graph-2.3.0.0-EuUH974vVM5LY5p3RL9zUg
    hls-plugin-api-2.3.0.0-4olhkqlfyGT9kusfBJKxhd
    lens-5.3.4-F4doVebWTE26Ky0GjDp5Se
    lsp-2.2.0.0-LmfZEBKj2mTJOChHjiUsY7 mtl-2.3.1 text-2.0.2
    transformers-0.6.1.0
    unordered-containers-0.2.20.1-HZplTUppwNB9GgXlMkO7HL

haddock-interfaces:
    /usr/share/doc/haskell-hls-explicit-imports-plugin/html/hls-explicit-imports-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-explicit-imports-plugin/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

